<?php

namespace App\Http\Controllers\api;

use App\Models\User;
use App\Models\ProgramMeal;
use App\Models\CustomerPlan;
use Illuminate\Http\Request;
use App\Models\CustomerAnswer;
use App\Models\ProgramExercise;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class CustomerAnswerController extends Controller
{
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'plan_id' => 'required',
            'question_id' => 'required',
            'answer' => 'required',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => true,
                'message' => $validator->errors()
            ], 401);
        } else {
            $user = new User();
            $user->name = $request->name;
            if ($request->device_token) {
                $user->device_token = $request->device_token;
            }
            if ($request->device_type) {
                $user->device_type = $request->device_type;
            }
            $user->save();

            $customer_id = $user->id;
            $plan_id = $request->plan_id;
            $customer_plan = new CustomerPlan();
            $customer_plan->customer_id = $customer_id;
            $customer_plan->plan_id = $plan_id;
            $customer_plan->save();

            $createdRecords = [];

            foreach ($request->question_id as $key => $value) {
                $customer_answer = new CustomerAnswer();
                $customer_answer->customer_id = $customer_id;
                $customer_answer->question_id = $value;

                if (is_array($request->answer) && isset($request->answer[$key])) {
                    if (is_array($request->answer[$key])) {
                        $customer_answer->answer = implode(',', $request->answer[$key]);
                    } else {
                        $customer_answer->answer = $request->answer[$key];
                    }
                } else {
                    $customer_answer->answer = $request->answer[$key];
                }

                if ($customer_answer->save()) {
                    $createdRecords[] = $customer_answer;
                }
            }


            $program_exercises = ProgramExercise::where('fitness_category_id', $plan_id)->get();
            $program_exercises_count = count($program_exercises);
            $dayAnswers = CustomerAnswer::whereHas('question.question_type', function ($query) {
                $query->where('name', 'Day');
            })->where('customer_id', $customer_id)->pluck('answer')->toArray();

            $organizedWeeks = [];
            $exerciseIndex = 0;

            foreach ($program_exercises as $exercise) {
                $week = [];

                foreach ($dayAnswers as $weekDays) {
                    foreach (['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'] as $day) {
                        if (in_array($day, explode(',', $weekDays))) {
                            $week[] = [
                                'day' => $day,
                                'exercise' => null,
                            ];
                        } elseif ($exerciseIndex < $program_exercises_count) {
                            $week[] = [
                                'day' => $day,
                                'exercise' => $program_exercises[$exerciseIndex],
                            ];
                            $exerciseIndex++;
                        }
                    }
                }

                if (!empty($week)) {
                    $organizedWeeks[] = $week;
                }

                if ($exerciseIndex >= $program_exercises_count) {
                    break; // All exercises have been assigned
                }
            }


            $program_meals = ProgramMeal::where('fitness_category_id', $plan_id)->get();
            if ($customer_answer->save()) {
                return response()->json([
                    'success' => true,
                    'message' => 'Customer answer saved successfully',
                    'customer_answer' => $createdRecords,
                    'organizedWeeks' => $organizedWeeks,
                    'program_meals' => $program_meals,
                ], 200);
            } else {
                return response()->json([
                    'success' => false,
                    'message' => 'Something went wrong',
                ], 401);
            }
        }
    }
}
