<?php

namespace App\Http\Controllers;

use App\Models\BMIRange;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class BMIRangeController extends Controller
{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $bmi_ranges = BMIRange::all();
        return view('admin.bmi_range.index', compact('bmi_ranges'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'bmi_from' => 'required|numeric',
            'bmi_to' => 'required|numeric',
        ]);

        if ($validator->fails()) {
            return redirect()->route('bmi-range.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $bmi_range = BMIRange::create($request->all());
            return redirect()->route('bmi-range.index')->with('success', 'BMI Range created successfully');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $bmi_range = BMIRange::find($id);
        return view('admin.bmi_range.edit', compact('bmi_range'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(), [
            'bmi_from' => 'required|numeric',
            'bmi_to' => 'required|numeric',
        ]);

        if ($validator->fails()) {
            return redirect()->route('bmi-range.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $bmi_range = BMIRange::find($id);
            $bmi_range->update($request->all());
            return redirect()->route('bmi-range.index')->with('success', 'BMI Range updated successfully');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $bmi_range = BMIRange::find($id);
        $bmi_range->delete();
        return redirect()->route('bmi-range.index')->with('success', 'BMI Range deleted successfully');
    }
}
