<?php

namespace App\Http\Controllers;

use App\Models\FitnessCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class FitnessCategoryController extends Controller
{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $fitness_categories = FitnessCategory::all();
        return view('admin.fitness_category.index', compact('fitness_categories'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|unique:fitness_categories,name|max:255',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return redirect()->route('fitness-category.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $fitness_category = FitnessCategory::create($request->all());
            return redirect()->route('fitness-category.index')->with('success', 'Fitness category created successfully');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $fitness_category = FitnessCategory::find($id);
        return view('admin.fitness_category.edit', compact('fitness_category'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|unique:fitness_categories,name,' . $id . '|max:255',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return redirect()->route('fitness-category.edit', $id)
                ->withErrors($validator)
                ->withInput();
        } else {
            $fitness_category = FitnessCategory::find($id);
            $fitness_category->update($request->all());
            return redirect()->route('fitness-category.index')->with('success', 'Fitness category updated successfully');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $fitness_category = FitnessCategory::find($id);
        $fitness_category->delete();
        return redirect()->route('fitness-category.index')->with('success', 'Fitness category deleted successfully');
    }
}
