<?php

namespace App\Http\Controllers;

use App\Models\BMIRange;
use App\Models\ProgramMeal;
use App\Models\BMIRangeMeal;
use Illuminate\Http\Request;
use App\Models\FitnessCategory;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class ProgramMealController extends Controller
{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $bmiRanges = BMIRange::all();
        $program_meals = ProgramMeal::all();
        $fitnessCategories = FitnessCategory::all();
        return view('admin.program_meal.index', compact('fitnessCategories', 'program_meals', 'bmiRanges'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'fitness_category_id' => 'required|integer',
            'bmi_range_id' => 'required|array',
            'bmi_range_id.*' => 'integer|exists:bmi_ranges,id',
            'gender' => 'required',
            'meal_name' => 'required|string',
            'calories' => 'required|integer',
            'protein' => 'required|integer',
            'carbs' => 'required|integer',
            'fats' => 'required|integer',
            'description' => 'required|string',
        ]);

        if ($validator->fails()) {
            return redirect()->route('program-meal.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $program_Meal = ProgramMeal::create($request->all());
            foreach ($request->input('bmi_range_id') as $bmirangeId) {
                $bmirangemeal = new BMIRangeMeal([
                    'bmi_range_id' => $bmirangeId,
                    'program_meal_id' => $program_Meal->id,
                ]);
                $bmirangemeal->save();
            }
            return redirect()->route('program-meal.index')->with('success', 'Program Meal created successfully');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $program_meal = ProgramMeal::find($id);
        $fitnessCategories = FitnessCategory::all();
        $bmi_ranges = BMIRange::all();
        return view('admin.program_meal.edit', compact('fitnessCategories', 'program_meal', 'bmi_ranges'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(), [
            'fitness_category_id' => 'required|integer',
            'bmi_range_id' => 'required|array',
            'bmi_range_id.*' => 'integer|exists:bmi_ranges,id',
            'gender' => 'required',
            'meal_name' => 'required|string',
            'calories' => 'required|integer',
            'protein' => 'required|integer',
            'carbs' => 'required|integer',
            'fats' => 'required|integer',
            'description' => 'required|string',
        ]);

        if ($validator->fails()) {
            return redirect()->route('program-meal.edit', $id)
                ->withErrors($validator)
                ->withInput();
        } else {
            $program_meal = ProgramMeal::find($id);
            $program_meal->update($request->all());
            // Delete existing BMIRangeExercise records for this program exercise
            $program_meal->bmi_range_meals()->delete();

            // Create new BMIRangeExercise records based on the updated request data
            foreach ($request->input('bmi_range_id') as $bmirangeId) {
                $bmirangemeal = new BMIRangeMeal([
                    'bmi_range_id' => $bmirangeId,
                    'program_meal_id' => $program_meal->id,
                ]);
                $bmirangemeal->save();
            }
            return redirect()->route('program-meal.index')->with('success', 'Program Meal updated successfully');
        }
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $program_meal = ProgramMeal::find($id);
        $program_meal->delete();
        return redirect()->route('program-meal.index')->with('success', 'Program Meal deleted successfully');
    }
}
