<?php

namespace App\Http\Controllers;

use App\Models\Question;
use App\Models\QuestionType;
use Illuminate\Http\Request;
use App\Models\FitnessCategory;
use Illuminate\Validation\Rule;
use App\Models\FitnessCategoryQuestion;
use Illuminate\Support\Facades\Validator;

class QuestionController extends Controller
{

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $fitness_categories = FitnessCategory::all();
        $question_types = QuestionType::all();
        $questions = Question::all();
        return view('admin.question.index', compact('fitness_categories', 'question_types', 'questions'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'question_type_id' => 'required|integer|exists:question_types,id',
            'question' => 'required|string|unique:questions,question|max:255',
            'fitness_category_id' => 'required|array',
            'fitness_category_id.*' => 'integer|exists:fitness_categories,id',
        ]);

        if ($validator->fails()) {
            return redirect()->route('question.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $question = Question::create([
                'question_type_id' => $request->input('question_type_id'),
                'question' => $request->input('question'),
            ]);

            foreach ($request->input('fitness_category_id') as $fitnessCategoryId) {
                $fitnessCategoryQuestion = new FitnessCategoryQuestion([
                    'fitness_category_id' => $fitnessCategoryId,
                    'question_id' => $question->id,
                ]);
                $fitnessCategoryQuestion->save();
            }

            return redirect()->route('question.index')->with('success', 'Question created successfully');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $fitness_categories = FitnessCategory::all();
        $question_types = QuestionType::all();
        $question = Question::find($id);
        return view('admin.question.edit', compact('question', 'fitness_categories', 'question_types'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'question_type_id' => 'required|integer|exists:question_types,id',
            'question' => [
                'required',
                'string',
                Rule::unique('questions')->ignore($id),
                'max:255'
            ],
            'fitness_category_id' => 'required|array',
            'fitness_category_id.*' => 'integer|exists:fitness_categories,id',
        ]);

        if ($validator->fails()) {
            return redirect()->route('question.edit', $id)
                ->withErrors($validator)
                ->withInput();
        } else {
            $question = Question::find($id);
            $question->question_type_id = $request->input('question_type_id');
            $question->question = $request->input('question');
            $question->save();

            $existingFitnessCategories = $question->fitnessCategoryQuestions()->pluck('fitness_category_id')->toArray();
            $newFitnessCategories = $request->input('fitness_category_id');

            $categoriesToRemove = array_diff($existingFitnessCategories, $newFitnessCategories);
            $categoriesToAdd = array_diff($newFitnessCategories, $existingFitnessCategories);

            FitnessCategoryQuestion::whereIn('fitness_category_id', $categoriesToRemove)->where('question_id', $id)->delete();

            foreach ($categoriesToAdd as $categoryId) {
                $fitnessCategoryQuestion = new FitnessCategoryQuestion([
                    'fitness_category_id' => $categoryId,
                    'question_id' => $question->id,
                ]);
                $fitnessCategoryQuestion->save();
            }

            return redirect()->route('question.index')->with('success', 'Question updated successfully');
        }
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $question = Question::findOrFail($id);
        $question->fitnessCategoryQuestions()->delete();
        $question->delete();

        return redirect()->route('question.index')->with('success', 'Question deleted successfully');
    }
}
