@extends('admin.layout.layout')
@section('content')
    <div class="card">
        <div class="card-body">
            <div class="row mb-3">
                <div class="col">
                    <h4 class="card-title">BMI Ranges</h4>
                </div>
                <div class="col text-end">
                    <button type="button" class="btn btn-primary text-white" data-bs-toggle="modal"
                        data-bs-target="#addBMIRangeModal">Add BMI Range</button>
                </div>
            </div>
            <div class="table-responsive">
                <table class="table table-striped" id="myTable">
                    <thead>
                        <tr>
                            <th>S.NO</th>
                            <th>BMI Range</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($bmi_ranges as $bmi_range)
                            <tr>
                                <td>{{ $loop->iteration }}</td>
                                <td>{{ $bmi_range->bmi_from }} - {{ $bmi_range->bmi_to }}</td>
                                <td>
                                    <div class="dropdown">
                                        <button class="btn btn-primary text-white dropdown-toggle dropdown-toggle-no-arrow"
                                            type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown"
                                            aria-expanded="false">
                                            <i class="bi bi-three-dots"></i>
                                        </button>

                                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('bmi-range.edit', $bmi_range->id) }}">
                                                    Edit
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('bmi-range.destroy', $bmi_range->id) }}"
                                                    onclick="event.preventDefault();
                                                        swal({
                                                            title: 'Are you sure?',
                                                            text: 'Once deleted, you will not be able to recover this bmi range!',
                                                            icon: 'warning',
                                                            buttons: true,
                                                            dangerMode: true,
                                                        }).then((willDelete) => {
                                                            if (willDelete) {
                                                                document.getElementById('delete-form-{{ $bmi_range->id }}').submit();
                                                            }
                                                        });">Delete
                                                </a>
                                                <form id="delete-form-{{ $bmi_range->id }}"
                                                    action="{{ route('bmi-range.destroy', $bmi_range->id) }}"
                                                    method="POST" style="display: none;">
                                                    @csrf
                                                    @method('DELETE')
                                                </form>
                                            </li>
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    {{-- Data Table Code --}}
    <script>
        let table = new DataTable('#myTable');
    </script>
    {{-- Opening modal if any error exists --}}
    @if ($errors->any())
        <script>
            $(document).ready(function() {
                $('#addBMIRangeModal').modal('show');
            });
        </script>
    @endif
    <!-- Modal -->
    <div class="modal fade" id="addBMIRangeModal" tabindex="-1" aria-labelledby="addBMIRangeModalLabel"
        aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addBMIRangeModalLabel">Add BMI Range</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="card">
                        <div class="card-body">
                            <form class="forms-sample" method="POST" action="{{ route('bmi-range.store') }}">
                                @csrf
                                <div class="form-group pt-3">
                                    <label>BMI From</label>
                                    <input type="text" class="form-control @error('bmi_from') is-invalid @enderror"
                                        name="bmi_from" id="bmi_from" placeholder="Enter BMI from"
                                        value="{{ old('bmi_from') }}" required>
                                    @error('bmi_from')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-group pt-3">
                                    <label>BMI To</label>
                                    <input type="text" class="form-control @error('bmi_to') is-invalid @enderror"
                                        name="bmi_to" id="bmi_to" placeholder="Enter BMI from"
                                        value="{{ old('bmi_to') }}" required>
                                    @error('bmi_to')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <button type="submit" class="btn btn-primary me-2 text-white">Submit</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
