@extends('admin.layout.layout')
@section('content')
    <div class="card">
        <div class="card-body">
            <div class="row mb-3">
                <div class="col">
                    <h4 class="card-title">Fitness Categories</h4>
                </div>
                <div class="col text-end">
                    <button type="button" class="btn btn-primary text-white" data-bs-toggle="modal"
                        data-bs-target="#addFitnessCategoryModal">Add Fitness Category</button>
                </div>
            </div>
            <div class="table-responsive">
                <table class="table table-striped" id="myTable">
                    <thead>
                        <tr>
                            <th>S.NO</th>
                            <th>Name</th>
                            <th>Type</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($fitness_categories as $fitness_category)
                            <tr>
                                <td>{{ $loop->iteration }}</td>
                                <td>{{ $fitness_category->name }}</td>
                                <td>{{ $fitness_category->type }}</td>
                                <td>
                                    <div class="dropdown">
                                        <button class="btn btn-primary text-white dropdown-toggle dropdown-toggle-no-arrow"
                                            type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown"
                                            aria-expanded="false">
                                            <i class="bi bi-three-dots"></i>
                                        </button>

                                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('fitness-category.edit', $fitness_category->id) }}">
                                                    Edit
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('fitness-category.destroy', $fitness_category->id) }}"
                                                    onclick="event.preventDefault();
                                                        swal({
                                                            title: 'Are you sure?',
                                                            text: 'Once deleted, you will not be able to recover this fitness category!',
                                                            icon: 'warning',
                                                            buttons: true,
                                                            dangerMode: true,
                                                        }).then((willDelete) => {
                                                            if (willDelete) {
                                                                document.getElementById('delete-form-{{ $fitness_category->id }}').submit();
                                                            }
                                                        });">Delete
                                                </a>
                                                <form id="delete-form-{{ $fitness_category->id }}"
                                                    action="{{ route('fitness-category.destroy', $fitness_category->id) }}"
                                                    method="POST" style="display: none;">
                                                    @csrf
                                                    @method('DELETE')
                                                </form>
                                            </li>
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    {{-- Data Table Code --}}
    <script>
        let table = new DataTable('#myTable');
    </script>
    {{-- Opening modal if any error exists --}}
    @if ($errors->any())
        <script>
            $(document).ready(function() {
                $('#addFitnessCategoryModal').modal('show');
            });
        </script>
    @endif
    <!-- Modal -->
    <div class="modal fade" id="addFitnessCategoryModal" tabindex="-1" aria-labelledby="addFitnessCategoryModalLabel"
        aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addFitnessCategoryModalLabel">Add Fitness Category</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="card">
                        <div class="card-body">
                            <form class="forms-sample" method="POST" action="{{ route('fitness-category.store') }}">
                                @csrf
                                <div class="form-group pt-3">
                                    <label>Fitness Category Name</label>
                                    <input type="text" class="form-control @error('name') is-invalid @enderror"
                                        name="name" id="name" placeholder="Enter fitness category name"
                                        value="{{ old('name') }}" required>
                                    @error('name')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-group pt-3">
                                    <label for="type">Type</label>
                                    <select class="form-control @error('type') is-invalid @enderror" id="type" name="type" required>
                                        <option value="">Select Type</option>
                                        <option value="normal">Normal</option>
                                        <option value="pro">Pro</option>
                                    </select>
                                    @error('type')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>

                                <button type="submit" class="btn btn-primary me-2 text-white">Submit</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
