@extends('admin.layout.layout')
@section('content')
    <div class="card">
        <div class="card-body">
            <div class="row mb-3">
                <div class="col">
                    <h4 class="card-title">Program Meal</h4>
                </div>
                <div class="col text-end">
                    <button type="button" class="btn btn-primary text-white" data-bs-toggle="modal"
                        data-bs-target="#addProgramMealModal">Add Program Meal</button>
                </div>
            </div>
            <div class="table-responsive">
                <table class="table table-striped" id="myTable">
                    <thead>
                        <tr>
                            <th>S.NO</th>
                            <th>Fitness Category</th>
                            <th>BMI</th>
                            <th>Gender</th>
                            <th>Meal Name</th>
                            <th>Calories</th>
                            <th>Protein</th>
                            <th>Carbs</th>
                            <th>Fats</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($program_meals as $program_meal)
                            <tr>
                                @php
                                    $bmi_ranges = [];
                                    foreach ($program_meal->bmi_range_meals as $bmi_range_meal) {
                                        $bmi_ranges[] = $bmi_range_meal->bmi_range->bmi_from . ' - ' . $bmi_range_meal->bmi_range->bmi_to;
                                    }
                                    $comma_separated_bmi = implode(', ', $bmi_ranges);
                                @endphp
                                <td>{{ $loop->iteration }}</td>
                                <td>{{ $program_meal->fitnessCategory->name }}</td>
                                <td>
                                    {{ $comma_separated_bmi }}
                                </td>
                                <td>{{ $program_meal->gender }}</td>
                                <td>{{ $program_meal->meal_name }}</td>
                                <td>{{ $program_meal->calories }}</td>
                                <td>{{ $program_meal->protein }}</td>
                                <td>{{ $program_meal->carbs }}</td>
                                <td>{{ $program_meal->fats }}</td>
                                <td>
                                    <div class="dropdown">
                                        <button class="btn btn-primary text-white dropdown-toggle dropdown-toggle-no-arrow"
                                            type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown"
                                            aria-expanded="false">
                                            <i class="bi bi-three-dots"></i>
                                        </button>

                                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('program-meal.edit', $program_meal->id) }}">
                                                    Edit
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('program-meal.destroy', $program_meal->id) }}"
                                                    onclick="event.preventDefault();
                                                        swal({
                                                            title: 'Are you sure?',
                                                            text: 'Once deleted, you will not be able to recover this program meal!',
                                                            icon: 'warning',
                                                            buttons: true,
                                                            dangerMode: true,
                                                        }).then((willDelete) => {
                                                            if (willDelete) {
                                                                document.getElementById('delete-form-{{ $program_meal->id }}').submit();
                                                            }
                                                        });">Delete
                                                </a>
                                                <form id="delete-form-{{ $program_meal->id }}"
                                                    action="{{ route('program-meal.destroy', $program_meal->id) }}"
                                                    method="POST" style="display: none;">
                                                    @csrf
                                                    @method('DELETE')
                                                </form>
                                            </li>
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    {{-- Data Table Code --}}
    <script>
        let table = new DataTable('#myTable');
    </script>
    {{-- Opening modal if any error exists --}}
    @if ($errors->any())
        <script>
            $(document).ready(function() {
                $('#addProgramMealModal').modal('show');
            });
        </script>
    @endif
    <!-- Modal -->
    <div class="modal fade" id="addProgramMealModal" tabindex="-1" aria-labelledby="addProgramMealModalLabel"
        aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addProgramMealModalLabel">Add Program Meal</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="card">
                        <div class="card-body">
                            <form class="forms-sample" method="POST" action="{{ route('program-meal.store') }}">
                                @csrf
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="fitness_category_id">Fitness Category</label>
                                            <select class="form-control @error('fitness_category_id') is-invalid @enderror"
                                                name="fitness_category_id" id="fitness_category_id" required>
                                                <option value="">Select Fitness Category</option>
                                                @foreach ($fitnessCategories as $fitnessCategory)
                                                    <option value="{{ $fitnessCategory->id }}"
                                                        {{ old('fitness_category_id') == $fitnessCategory->id ? 'selected' : '' }}>
                                                        {{ $fitnessCategory->name }}</option>
                                                @endforeach
                                            </select>
                                            @error('fitness_category_id')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="gender">Gender</label>
                                            <select class="form-control @error('gender') is-invalid @enderror"
                                                name="gender" id="gender" required>
                                                <option value="">Select Gender</option>
                                                <option value="male" {{ old('gender') === 'male' ? 'selected' : '' }}>
                                                    Male</option>
                                                <option value="female" {{ old('gender') === 'female' ? 'selected' : '' }}>
                                                    Female</option>
                                                <option value="other" {{ old('gender') === 'other' ? 'selected' : '' }}>
                                                    Other</option>
                                            </select>
                                            @error('gender')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="form-group pt-3">
                                        <label for="bmi_range_id">BMI Range</label>
                                        <div class="row">
                                            @foreach ($bmiRanges as $bmiRange)
                                                <div class="col-3">
                                                    <div class="form-check form-check-inline">
                                                        <input
                                                            class="form-check-input ms-1 @error('bmi_range_id') is-invalid @enderror"
                                                            type="checkbox" name="bmi_range_id[]"
                                                            id="bmi_range_id{{ $bmiRange->id }}"
                                                            value="{{ $bmiRange->id }}"
                                                            @if (is_array(old('bmi_range_id')) && in_array($bmiRange->id, old('bmi_range_id'))) checked @endif required>
                                                        <label class="form-check-label"
                                                            for="bmi_range_id{{ $bmiRange->id }}">
                                                            {{ $bmiRange->bmi_from }} - {{ $bmiRange->bmi_to }}
                                                        </label>
                                                    </div>
                                                </div>
                                            @endforeach
                                            @error('bmi_range_id')
                                                <div class="col-12">
                                                    <div class="invalid-feedback">{{ $message }}</div>
                                                </div>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="meal_name">Meal Name</label>
                                            <input type="text"
                                                class="form-control @error('meal_name') is-invalid @enderror"
                                                name="meal_name" id="meal_name" placeholder="Enter Exercise Day"
                                                value="{{ old('meal_name') }}" required>
                                            @error('meal_name')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="calories">Calories</label>
                                            <span class="text-danger small">(kcal)</span>
                                            <input type="number"
                                                class="form-control @error('calories') is-invalid @enderror"
                                                name="calories" id="calories" placeholder="Enter Calories"
                                                value="{{ old('calories') }}" required>
                                            @error('calories')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="protein">Protein</label>
                                            <span class="text-danger small">(grams)</span>
                                            <input type="number"
                                                class="form-control @error('protein') is-invalid @enderror" name="protein"
                                                id="protein" placeholder="Enter Protein" value="{{ old('protein') }}"
                                                required>
                                            @error('protein')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="carbs">Carbs</label>
                                            <span class="text-danger small">(grams)</span>
                                            <input type="number"
                                                class="form-control @error('carbs') is-invalid @enderror" name="carbs"
                                                id="carbs" placeholder="Enter Carbs" value="{{ old('carbs') }}"
                                                required>
                                            @error('carbs')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="fats">Fats</label>
                                            <span class="text-danger small">(grams)</span>
                                            <input type="number" class="form-control @error('fats') is-invalid @enderror"
                                                name="fats" id="fats" placeholder="Enter Fats"
                                                value="{{ old('fats') }}" required>
                                            @error('fats')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="description">Description</label>
                                            <textarea class="form-control @error('description') is-invalid @enderror" name="description" id="description"
                                                placeholder="Enter Description" rows="4" required>{{ old('description') }}</textarea>
                                            @error('description')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                    {{-- submit button --}}
                                    <div class="col-md-12">
                                        <button type="submit" class="btn btn-primary mr-2 text-white">Submit</button>
                                    </div>
                                </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script>
        const checkboxes = document.querySelectorAll('input[type=checkbox][name="bmi_range_id[]"]');

        const setCheckboxRequired = () => {
            const checked = Array.from(checkboxes).some((c) => c.checked);
            checkboxes.forEach((c) => c.required = !checked);
        }

        checkboxes.forEach((checkbox) => {
            checkbox.addEventListener('click', setCheckboxRequired);
        });

        // set checkbox required initially if no checkbox is checked
        setCheckboxRequired();
    </script>
@endsection
